==> open_watcom_1.4.0-src.zip: bld/f77/wfc/c/gcnvt.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


//
// GCNVT     : type conversion
//

#include "ftnstd.h"
#include "global.h"
#include "fcodes.h"
#include "parmtype.h"

extern  void            EmitOp(unsigned_16);
extern  void            OutU16(unsigned_16);


void    GILCnvTo( uint typ, uint size ) {
//=======================================

// Convert operand to given type.

    GCnvTo( typ, size );
}


static  void    GCnvTo( uint typ, uint size ) {
//=============================================

// Convert operand.

    EmitOp( CONVERT );
    OutU16( ( ParmType( CITNode->typ, CITNode->size ) << 8 ) |
              ParmType( typ, size ) );
    CITNode->typ = typ;
    CITNode->size = size;
}


void    GIChar() {
//================

    EmitOp( ICHAR );
}

==> open_watcom_1.5.0-src.zip: bld/f77/wfc/c/gcnvt.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


//
// GCNVT     : type conversion
//

#include "ftnstd.h"
#include "global.h"
#include "fcodes.h"
#include "types.h"
#include "emitobj.h"


static  void    GCnvTo( TYPE typ, uint size ) {
//=============================================

// Convert operand.

    EmitOp( FC_CONVERT );
    DumpTypes( CITNode->typ, CITNode->size, typ, size );
    CITNode->typ = typ;
    CITNode->size = size;
}


void    GILCnvTo( TYPE typ, uint size ) {
//=======================================

// Convert operand to given type.

    GCnvTo( typ, size );
}


void    GIChar() {
//================

    EmitOp( FC_ICHAR );
}
